@@ -22,20 +22,16 @@ from datetime import datetime, date, time, timedelta
 from enum import Enum
 from locale import LC_ALL, setlocale
 from threading import RLock
-from typing import TYPE_CHECKING, Union, Iterator, Collection, Sequence, Optional, Generic, TypeVar, Type, overload
+from typing import Union, Iterator, Collection, Sequence, Optional, TypeVar, Type, overload
 from typing import Tuple, Dict
 
+from ..typing import T, Bool, Locale, TimeBound
 from ..utils import MissingMixin
 from .base import InputType
 from .exceptions import InputValidationError, InvalidChoiceError
 
-if TYPE_CHECKING:
-    from ..utils import Bool
-
 __all__ = ['DTFormatMode', 'Day', 'Month', 'DateTime', 'Date', 'Time']
 
-Locale = Union[str, Tuple[Optional[str], Optional[str]]]
-TimeBound = Union[datetime, date, time, timedelta, None]
 DT = TypeVar('DT')
 
 DEFAULT_DATE_FMT = '%Y-%m-%d'
@@ -77,7 +73,7 @@ class different_locale:
         self._lock.release()
 
 
-class DTInput(InputType, ABC):
+class DTInput(InputType[T], ABC):
     dt_type: str
     locale: Optional[Locale]
 
@@ -88,9 +84,14 @@ class DTInput(InputType, ABC):
         self.locale = locale
 
     @abstractmethod
-    def choice_str(self, choice_delim: str = ',') -> str:
+    def choice_str(self, choice_delim: str = ',', sort_choices: bool = False) -> str:
         raise NotImplementedError
 
+    def fix_default(self, value: Union[str, T, None]) -> Optional[T]:
+        if value is None or not isinstance(value, str):
+            return value
+        return self(value)
+
 
 # region Calendar Unit Inputs
 
@@ -102,7 +103,7 @@ class DTFormatMode(MissingMixin, Enum):
     NUMERIC_ISO = 'numeric_iso'     #: The ISO numeric representation of a given date/time unit
 
 
-class CalendarUnitInput(DTInput, ABC):
+class CalendarUnitInput(DTInput[Union[str, int]], ABC):
     _formats: Dict[DTFormatMode, Sequence[Union[str, int]]]
     _min_index: int = 0
 
@@ -151,20 +152,22 @@ class CalendarUnitInput(DTInput, ABC):
             if self.abbreviation:
                 yield from enumerate(self._formats[DTFormatMode.ABBREVIATION][min_index:], min_index)
 
-    def choices(self) -> Sequence[str]:
+    def choices(self, sort: bool = False) -> Sequence[str]:
         choices = [dow for _, dow in self._values()]
         if self.numeric:
             mode = DTFormatMode.NUMERIC_ISO if getattr(self, 'iso', False) else DTFormatMode.NUMERIC
             # fmt: off
             choices.extend(map(str, self._formats[mode][self._min_index:]))
             # fmt: on
+        if sort:
+            choices.sort()
         return choices
 
-    def choice_str(self, choice_delim: str = ',') -> str:
-        return choice_delim.join(self.choices())
+    def choice_str(self, choice_delim: str = ',', sort_choices: bool = False) -> str:
+        return choice_delim.join(self.choices(sort_choices))
 
-    def format_metavar(self, choice_delim: str = ',') -> str:
-        return '{' + self.choice_str(choice_delim) + '}'
+    def format_metavar(self, choice_delim: str = ',', sort_choices: bool = False) -> str:
+        return '{' + self.choice_str(choice_delim, sort_choices) + '}'
 
     @abstractmethod
     def parse_numeric(self, value: str) -> int:
@@ -325,7 +328,7 @@ class Month(CalendarUnitInput, dt_type='month', min_index=1):
 # region Date/Time Parse Inputs
 
 
-class DateTimeInput(Generic[DT], DTInput, ABC):
+class DateTimeInput(DTInput[DT], ABC):
     formats: Collection[str]
     _type: Type[DT]
     _earliest: TimeBound = None
@@ -393,11 +396,11 @@ class DateTimeInput(Generic[DT], DTInput, ABC):
     def parse(self, value: str) -> DT:
         return self._fix_type(self.parse_dt(value))
 
-    def choice_str(self, choice_delim: str = ' | ') -> str:
-        return choice_delim.join(self.formats)
+    def choice_str(self, choice_delim: str = ' | ', sort_choices: bool = False) -> str:
+        return choice_delim.join(sorted(self.formats) if sort_choices else self.formats)
 
-    def format_metavar(self, choice_delim: str = ' | ') -> str:
-        choices = '{' + self.choice_str(choice_delim) + '}'
+    def format_metavar(self, choice_delim: str = ' | ', sort_choices: bool = False) -> str:
+        choices = '{' + self.choice_str(choice_delim, sort_choices) + '}'
         earliest, latest = self.earliest, self.latest
         prefix = f'{dt_repr(earliest, False)} <= ' if earliest is not None else ''
         suffix = f' <= {dt_repr(latest, False)}' if latest is not None else ''
